info = {
    "name": "my",
    "date_order": "DMY",
    "january": [
        "ဇန်",
        "ဇန်နဝါရီ"
    ],
    "february": [
        "ဖေ",
        "ဖေဖော်ဝါရီ"
    ],
    "march": [
        "မတ်"
    ],
    "april": [
        "ဧ",
        "ဧပြီ"
    ],
    "may": [
        "မေ"
    ],
    "june": [
        "ဇွန်"
    ],
    "july": [
        "ဇူ",
        "ဇူလိုင်"
    ],
    "august": [
        "ဩ",
        "ဩဂုတ်"
    ],
    "september": [
        "စက်",
        "စက်တင်ဘာ"
    ],
    "october": [
        "အောက်",
        "အောက်တိုဘာ"
    ],
    "november": [
        "နို",
        "နိုဝင်ဘာ"
    ],
    "december": [
        "ဒီ",
        "ဒီဇင်ဘာ"
    ],
    "monday": [
        "တနင်္လာ"
    ],
    "tuesday": [
        "အင်္ဂါ"
    ],
    "wednesday": [
        "ဗုဒ္ဓဟူး"
    ],
    "thursday": [
        "ကြာသပတေး"
    ],
    "friday": [
        "သောကြာ"
    ],
    "saturday": [
        "စနေ"
    ],
    "sunday": [
        "တနင်္ဂနွေ"
    ],
    "am": [
        "နံနက်"
    ],
    "pm": [
        "ညနေ"
    ],
    "year": [
        "နှစ်"
    ],
    "month": [
        "လ"
    ],
    "week": [
        "ပတ်"
    ],
    "day": [
        "ရက်"
    ],
    "hour": [
        "နာရီ"
    ],
    "minute": [
        "မိနစ်"
    ],
    "second": [
        "စက္ကန့်"
    ],
    "relative-type": {
        "0 day ago": [
            "ယနေ့"
        ],
        "0 hour ago": [
            "ဤအချိန်"
        ],
        "0 minute ago": [
            "ဤမိနစ်"
        ],
        "0 month ago": [
            "ယခုလ"
        ],
        "0 second ago": [
            "ယခု"
        ],
        "0 week ago": [
            "ယခု သီတင်းပတ်"
        ],
        "0 year ago": [
            "ယခုနှစ်"
        ],
        "1 day ago": [
            "မနေ့က"
        ],
        "1 month ago": [
            "ပြီးခဲ့သည့်လ"
        ],
        "1 week ago": [
            "ပြီးခဲ့သည့် သီတင်းပတ်"
        ],
        "1 year ago": [
            "ယမန်နှစ်"
        ],
        "in 1 day": [
            "မနက်ဖြန်"
        ],
        "in 1 month": [
            "လာမည့်လ"
        ],
        "in 1 week": [
            "လာမည့် သီတင်းပတ်"
        ],
        "in 1 year": [
            "လာမည့်နှစ်"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "ပြီးခဲ့သည့် (\\d+) ရက်"
        ],
        "\\1 hour ago": [
            "ပြီးခဲ့သည့် (\\d+) နာရီ"
        ],
        "\\1 minute ago": [
            "ပြီးခဲ့သည့် (\\d+) မိနစ်"
        ],
        "\\1 month ago": [
            "ပြီးခဲ့သည့် (\\d+) လ"
        ],
        "\\1 second ago": [
            "ပြီးခဲ့သည့် (\\d+) စက္ကန့်"
        ],
        "\\1 week ago": [
            "ပြီးခဲ့သည့် (\\d+) ပတ်"
        ],
        "\\1 year ago": [
            "ပြီးခဲ့သည့် (\\d+) နှစ်"
        ],
        "in \\1 day": [
            "(\\d+) ရက်အတွင်း"
        ],
        "in \\1 hour": [
            "(\\d+) နာရီအတွင်း"
        ],
        "in \\1 minute": [
            "(\\d+) မိနစ်အတွင်း"
        ],
        "in \\1 month": [
            "(\\d+) လအတွင်း"
        ],
        "in \\1 second": [
            "(\\d+) စက္ကန့်အတွင်း"
        ],
        "in \\1 week": [
            "(\\d+) ပတ်အတွင်း"
        ],
        "in \\1 year": [
            "(\\d+) နှစ်အတွင်း"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
